#include <ldas_tools_config.h>

#include <iostream>

#include "ldastoolsal/MemChecker.hh"

#include "diskcacheAPI/Cache/RegistrySingleton.hh"

namespace diskCache
{
  namespace Cache
  {
    SINGLETON_TS_INST( RegistrySingleton );

    const RegistrySingleton::id_type RegistrySingleton::ID_NULL = 0;

    /** \cond ignore_singleton_constructor */
    RegistrySingleton::
    RegistrySingleton( )
      : Cache::Registry( )
    {
      LDASTools::AL::MemChecker::Append( singleton_suicide,
					 "diskCache::Cache::RegistrySingleton",
					 50 );
    }
    /** \endcond */

  } // namespace - Cache
} // namespace - diskCache
